@@ -46,4 +46,18 @@ def show(**kwargs):
             }
             print(json.dumps(response))
         except:
-            print('orangelib 에러: show function ')
\ No newline at end of file
+            print('orangelib 에러: show function ')
+
+def export(**kwargs):
+    df = kwargs.get('df', None)
+    if df is None:
+        wprint_dataframe()
+    else:
+        try:
+            response = {
+                'exportType': 'data',
+                'rows': df.to_json(orient='records'),
+            }
+            print(json.dumps(response))
+        except:
+            print('orangelib 에러: export function ')
\ No newline at end of file
